/*
 * This is the license for the control panel pattern example files.
 * 
 * Copyright (C) 2008 Johan Thelin <johan.thelin@bitsim.com>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the
 * following conditions are met:
 * 
 *   - Redistributions of source code must retain the above
 *     copyright notice, this list of conditions and the
 *     following disclaimer.
 *   - Redistributions in binary form must reproduce the
 *     above copyright notice, this list of conditions and
 *     the following disclaimer in the documentation and/or
 *     other materials provided with the distribution.
 *   - The names of its contributors may be used to endorse
 *     or promote products derived from this software without
 *     specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "recordingdetailspanel.h"

#include "recordings.h"
#include "recordingspanel.h"
#include "panelstack.h"

RecordingDetailsPanel *RecordingDetailsPanel::m_instance = 0;
RecordingDetailsPanel *RecordingDetailsPanel::instance()
{
	if( !m_instance )
	{
		m_instance = new RecordingDetailsPanel();
		m_instance->addPanelToStack();
	}

	return m_instance;
}

RecordingDetailsPanel::RecordingDetailsPanel() : AbstractPanel()
{
	ui.setupUi( this );

	connect( ui.saveButton, SIGNAL(clicked()), SLOT(saveClicked()) );
	connect( ui.discardButton, SIGNAL(clicked()), SLOT(discardClicked()) );
}

void RecordingDetailsPanel::showPanel( int recordingIndex )
{
	m_currentIndex = recordingIndex;

	if( m_currentIndex == -1 )
		ui.lineEdit->setText( "" );
	else
		ui.lineEdit->setText( recordings[ m_currentIndex ] );

	PanelStack::instance()->showPanel( panelIndex() );

	ui.lineEdit->setFocus();
}

void RecordingDetailsPanel::saveClicked()
{
	if( m_currentIndex == -1 )
		recordings << ui.lineEdit->text();
	else
		recordings[ m_currentIndex ] = ui.lineEdit->text();

	RecordingsPanel::instance()->showPanel();
}

void RecordingDetailsPanel::discardClicked()
{
	RecordingsPanel::instance()->showPanel();
}
